clear
close all
clc

%%
Years = [1959 1965 1971 1974 1977 2008];
Inds = Years-1958+1;

models = {'sl', 'sbh'};
par = 200;
parNames = {'k', 'S'; 'R', 'S'};
sigmas = 1.0;
isig = 1;

%%
load SR_modeloutput_3Pscod_revised.mat
T = [Data(1,1)-1 Data(:,1)'];

%%
lstys = {'-'};

%%
f = figure(15136);
ar = 3.0;
h = 350;
f.Position = [41 73 ar*h h];
clf

%%
load Results\mat\uniform_sigma2_0.0-1.0_k_0-200_Sk_0-200_sl.mat
pDEP(1,1,:) = fliplr([Results(:,3).pDEP]);

load Results\mat\uniform_sigma2_0.0-1.0_Rinf_0-200_Sq_0-200_sbh.mat
pDEP(1,2,:) = fliplr([Results(:,4).pDEP]);

%%
ax(1) = subplot(1,2,1);
ax(1).NextPlot = 'add';
ax(2) = subplot(1,2,2);
ax(2).NextPlot = 'add';

colors = [0 0.447 0.741 ; 0.85 0.325 0.098];

for is = 1:length(sigmas)
    for im = 1:length(models)
        color = colors(im, :);
        YData = squeeze(pDEP(is, im, :));
        h(im) = plot(ax(1), T, YData, ...
            'linestyle', lstys{is}, 'color', color, ...
            'linewidth', 2);
        hold on
        h(im+2) = plot(ax(1), T(Inds), YData(Inds), ...
            'linestyle', 'none', 'color', color, ...
            'marker', '.', 'markersize', 20);
        
        box off
        ax(1).TickDir = 'out';
        ax(1).XAxis.TickLabelRotation = 90;
        ax(1).YLim = [0 1];
        ax(1).XLim = T([1 end]);
        
    end
end

%%
l1 = legend(ax(1), h(1:2), 'SL', 'SBH');
l1.FontSize = 14;
l1.Location = 'southwest';
l1.Box = 'off';

ax(1).YLabel.String = 'P(c > 1)';
ax(1).XLabel.String = 'Year';

%%
set(ax, 'FontSize', 14)

%%
set(ax(1), 'YTick', 0:0.2:1)
set(ax(1), 'YTickLabel', {'0.0' '0.2' '0.4' '0.6' '0.8' '1.0'})
set(ax(1), 'XMinorTick', 'on')
set(ax(1), 'XTick', 1960:5:2020)
set(ax(1).XAxis, 'MinorTickValue', T)

%%
load Results\mat\WAIC_sensitivity.mat
load SR_modeloutput_3Pscod_revised.mat
Year = Data(:,1);

colors = [0.0000 0.4470 0.7410 ;
          0.8500 0.3250 0.0980 ;
          0.4940 0.1840 0.5560 ;
          0.9290 0.6940 0.1250];

total = zeros(4,size(WAIC,3));
for im = 1:4
    total(im,:) = squeeze(WAIC(im,isig,:));
end
total = total([3 4 1 2], :);

XData = fliplr(Year);
XData = [XData(1)-1 ; XData];
YDATA = flipud(total')-fliplr(mean(total))';
YDATA = [NaN*ones(2,4) ; YDATA];
for i = 1:4
    h(i) = plot(ax(2), XData, YDATA(:,i), 'LineWidth', 2, 'Color', colors(i,:));
    hold on
end

for i = 1:4
    h2(i) = plot(ax(2), XData(Inds), YDATA(Inds,i), 'LineWidth', 2, ...
        'Color', colors(i,:), 'LineStyle', 'none', 'Marker', '.', ...
        'MarkerSize', 20);
    hold on
end

box off
ax(2).TickDir = 'out';
ax(2).FontSize = 14;

%%
ax(2).YLim = [-15 15];

%%
l = legend('SL', 'SBH', 'RI', 'BH');

l.FontSize = 14;
l.Location = 'southwest';
l.Box = 'off';

xlabel('Year')
ylabel('Score')

set(ax(2), 'XMinorTick', 'on')
set(ax(2), 'XTick', 1960:5:2020)
set(ax(2).XAxis, 'MinorTickValue', T)
ax(2).XAxis.TickLabelRotation = 90;
ax(2).XLim = T([3 end]);

%%
nrows = 1;
ncols = 2;

y0 = 0.26;
yp = 0.04;
ym = 0.075;
h = (1 - y0 - (nrows-1)*yp - ym)/nrows;

x0 = 0.07;
xp = 0.07;
xm = 0.01;
w = (1 - x0 - (ncols-1)*xp - xm)/ncols;
%
for ir = 1:nrows
    for ic = 1:ncols
        ax(ncols*(ir-1)+ic).Position = [x0+(ncols-ic)*(xp+w) y0+(ir-1)*(yp+h) w h];
    end
end

%%
axes(ax(2))
hta = text(0, 0, 'a)');
hta.Units = 'normalized';
hta.Position = [0.015 0.95 0];
hta.FontSize = 16;

axes(ax(1))
htb = text(0, 0, 'b)');
htb.Units = 'normalized';
htb.Position = [0.015 0.95 0];
htb.FontSize = 16;

%%
print(sprintf('%s/%s/FigS4.%s', 'Results', 'png', 'png'), '-dpng', '-r600')
hgsave(sprintf('%s/%s/FigS4.%s', 'Results', 'fig', 'fig'))