clearvars
close all
clc

%% CHOOSE WHICH FIGURES TO PLOT
plotR = true;
plotRpS = true;
plotC = true;
plotS0 = true;
plotParams = true;
plotSigma2 = true;

%% SAMPLER OPTIONS
warmup = 1000;
iter = 1000;
% warmup = 10000;
% iter = 100000;
chains = 1;
thin = 1;

reps = 10; % increase the smoothness of uncertainty envelopes in figures

%% FIGURE OPTIONS
qlow = 0.16;
qup = 0.84;

%% PARAMETER UPPER LIMITS
sigmaUp = 1;

% Main results
par1Up = 200;
par2Up = 200;

%% STOCK-RECRUITMENT MODELS
RSmodels = {'r', 'bh', 'sl', 'sbh'};
I = 1:4;
RSmodels = RSmodels(I);

Paramnames{1} = {'k', 'Sk'};
Paramnames{2} = {'Rinf', 'Sq'};
Paramnames{3} = {'k', 'Sk'};
Paramnames{4} = {'Rinf', 'Sq'};

%% RESULTS LOCATION
resultLoc = [cd '\Results'];

if ~exist([resultLoc '/fig'], 'dir')
    mkdir([resultLoc '/fig'])
end

if ~exist([resultLoc '/png'], 'dir')
    mkdir([resultLoc '/png'])
end

if ~exist([resultLoc '/mat'], 'dir')
    mkdir([resultLoc '/mat'])
end


%% PRIOR LIMITS
kLow = 0; kUp = par2Up;
SkLow = 0; SkUp = par1Up;
cLow = 0; cUp = 5;
sigmaLow = 0; sigmaUp = sigmaUp;
RinfLow = 0; RinfUp = par2Up;
SqLow = 0; SqUp = par1Up;

q = 0.5;

sigma2Low = sigmaLow^2;
sigma2Up = sigmaUp^2;

%% DATA FILENAMES
pathname = '';

fname = 'SR_modeloutput_3Pscod_revised.mat';
slabel = '3PScod';

%% MODEL FILENAME PRIOR IDENTIFIER STRING
prior = 'uniform_sigma2';

%% COMPILE MODELS
for irs = 1:length(RSmodels)
    model_file = sprintf('stan/%s_%s_model.stan', RSmodels{irs}, prior);
    model{irs} = StanModel('file', model_file);
    model_1dp_file = sprintf('stan/%s_%s_model_1dp.stan', RSmodels{irs}, prior);
    model_1dp{irs} = StanModel('file', model_1dp_file);
    model_0dp_file = sprintf('stan/%s_%s_model_0dp.stan', RSmodels{irs}, prior);
    model_0dp{irs} = StanModel('file', model_0dp_file);
    
    model{irs}.compile();
    model_1dp{irs}.compile();
    model_0dp{irs}.compile();
end

%% LOAD SR DATA
load([pathname fname])

R = Data(:, 3);
S = Data(:, 2);
Year = Data(:, 1);

nans = isnan(R) | isnan(S);
R(nans) = [];
S(nans) = [];
Year(nans) = [];

T = length(R);

XLim = [0 1.1*max(S)];

%% INITIAL VALUES FOR THE SAMPLER
k_0 = mean([kLow kUp]);
Sk_0 = mean([SkLow SkUp]);
Rinf_0 = mean([RinfLow RinfUp]);
Sq_0 = mean([SqLow SqUp]);
c_0 = mean([cLow cUp]);
sigma2_0 = mean([sigma2Low sigma2Up]);

%%
ns = length(S)+1; % Number of time steps for sequential model fits

% number of rows and columns for sequential model fit multipanel figures
ncols = ceil(sqrt(ns));
nrows = ceil(ns/ncols);

%%
for i = 1:ns
    if i > 1
        S(end) = [];
        R(end) = [];
        T = length(R);
    end
    
    for j = 1:length(RSmodels)
        if plotR
            f(j) = figure(j*10000+1);
            f(j).Units = 'normalized';
            f(j).OuterPosition = [0 0.032 1 0.968];
            subplot(nrows, ncols, i)
            plot(S, R, '--ob')
            hold on
            set(gca, 'XLim', XLim)
            box off
        end
        
        if plotRpS
            f(j) = figure(j*10000-1);
            f(j).Units = 'normalized';
            f(j).OuterPosition = [0 0.032 1 0.968];
            subplot(nrows, ncols, i)
            plot(S, R./S, '--ob')
            hold on
            set(gca, 'XLim', XLim)
            box off
        end
    end
    
    %% DATA STRUCTS FOR STAN
    dat{1} = struct('T', T, 'R', R, 'S', S, ...
        'kLow', kLow, 'kUp', kUp, 'SkLow', SkLow, 'SkUp', SkUp, ...
        'sigmaLow', sigmaLow, 'sigmaUp', sigmaUp);
    dat{2} = struct('T', T, 'R', R, 'S', S, 'q', q, ...
        'RinfLow', RinfLow, 'RinfUp', RinfUp, 'SqLow', SqLow, 'SqUp', SqUp, ...
        'sigmaLow', sigmaLow, 'sigmaUp', sigmaUp);
    dat{3} = struct('T', T, 'R', R, 'S', S, ...
        'kLow', kLow, 'kUp', kUp, 'SkLow', SkLow, 'SkUp', SkUp, ...
        'cLow', cLow, 'cUp', cUp, 'sigmaLow', sigmaLow, 'sigmaUp', sigmaUp);
    dat{4} = struct('T', T, 'R', R, 'S', S,  'q', q, ...
        'RinfLow', RinfLow, 'RinfUp', RinfUp, 'SqLow', SqLow, 'SqUp', SqUp, ...
        'cLow', cLow, 'cUp', cUp, 'sigmaLow', sigmaLow, 'sigmaUp', sigmaUp);
    
    dat = dat(I);
    %% INITIAL VALUE STRUCTS FOR STAN
    inits{1} = struct('k', k_0, 'Sk', Sk_0, 'sigma2', sigma2_0);
    inits{2} = struct('Rinf', Rinf_0, 'Sq', Sq_0, 'sigma2', sigma2_0);
    inits{3} = struct('k', k_0, 'Sk', Sk_0, 'c', c_0, 'sigma2', sigma2_0);
    inits{4} = struct('Rinf', Rinf_0, 'Sq', Sq_0, 'c', c_0, 'sigma2', sigma2_0);
    
    inits = inits(I);
    %% LOOP OVER MODELS
    for j = 1:length(RSmodels)
        % FIT THE MODEL
        % Need separate model definition files for 0, 1 and 2+ observations
        if T > 1
            fit(i, j) = model{j}.sampling('data', dat{j}, 'iter', iter, 'thin', thin, ...
                'chains', chains, 'warmup', warmup, 'init', inits{j});
        elseif T == 1
            fit(i, j) = model_1dp{j}.sampling('data', dat{j}, 'iter', iter, 'thin', thin, ...
                'chains', chains, 'warmup', warmup, 'init', inits{j});
        elseif T == 0
            dat_0dp{j} = rmfield(dat{j}, {'R', 'S', 'T'});
            fit(i, j) = model_0dp{j}.sampling('data', dat_0dp{j}, 'iter', iter, 'thin', thin, ...
                'chains', chains, 'warmup', warmup, 'init', inits{j});
        end
        fit(i,j).verbose = true;
        fit(i,j).block();
        
        %% EXTRACT THE RESULTS FROM STANFIT OBJECT 
        sigma = fit(i, j).extract.sigma;
        sigma2 = fit(i, j).extract.sigma2;
        switch I(j)
            case 1
                k = fit(i, j).extract.k;
                Sk = fit(i, j).extract.Sk;
                Params = {k, Sk};
                ParamLims = {[kLow kUp], [SkLow SkUp]};
            case 2
                Rinf = fit(i, j).extract.Rinf;
                Sq = fit(i, j).extract.Sq;
                Params = {Rinf, Sq};
                ParamLims = {[RinfLow RinfUp], [SqLow SqUp]};
            case 3
                k = fit(i, j).extract.k;
                Sk = fit(i, j).extract.Sk;
                c = fit(i, j).extract.c;
                Params = {k, Sk};
                ParamLims = {[kLow kUp], [SkLow SkUp]};
                S0 = (1-1./sqrt(c)).*Sk;
            case 4
                Rinf = fit(i, j).extract.Rinf;
                Sq = fit(i, j).extract.Sq;
                c = fit(i, j).extract.c;
                Params = {Rinf, Sq};
                ParamLims = {[RinfLow RinfUp], [SqLow SqUp]};
                S0 = Sq./(q.^(1./c).*(-1./((c - 1)*(q - 1))).^(1./c).*(c + 1).^(1./c));
                %S0 = S50./((c+1)./(c-1))^(1./c);
        end
        
        %% CALCULATE WAIC (Vehtari and Gelman, 2014)
        if T > 0
            log_lik = fit(i, j).extract.log_lik;
            Results(i, j).waic = calculateWaic(log_lik, iter, T);
        end
        
        % CALCULATE INTERESTING QUANTITIES
        if strcmp(RSmodels{j}, 'sl') || strcmp(RSmodels{j}, 'sbh')
            Results(i, j).varC = var(c);
            Results(i, j).stdC = std(c);
            Results(i, j).cpi68C = [quantile(c, 0.16) quantile(c, 0.84)];
            Results(i, j).cpi95C = [quantile(c, 0.025) quantile(c, 0.975)];
            Results(i, j).wcpi68C = abs(diff(Results(i, j).cpi68C));
            Results(i, j).wcpi95C = abs(diff(Results(i, j).cpi95C));
            Results(i, j).pDEP = mean(c > 1);
            if i == 1
                Results(i, j).S0 = S0;
            end
        end
        
        % CALCULATE LOG PREDICTIVE DENSITY SCORES
        if T > 0
            SS = repmat(S', iter, 1);
            switch I(j)
                case 1
                    K = repmat(k, 1, T);
                    SK = repmat(Sk, 1, T);
                    ER = K.*(SS./SK).*exp(1-SS./SK);
                case 2
                    RINF = repmat(Rinf, 1, T);
                    SQ = repmat(Sq, 1, T);
                    ER = RINF./((1-q)/q*(SQ./SS)+1);
                case 3
                    K = repmat(k, 1, T);
                    SK = repmat(Sk, 1, T);
                    C = repmat(c, 1, T);
                    ER = K.*(SS./SK).^C.*exp(C.*(1-SS./SK));
                case 4
                    RINF = repmat(Rinf, 1, T);
                    SQ = repmat(Sq, 1, T);
                    C = repmat(c, 1, T);
                    ER = RINF./((1-q)/q*(SQ./SS).^C+1);
            end
            muR = log(ER) - 0.5*sigma2;
            Results(i, j).lpd = log(mean(lognpdf(repmat(R', iter, 1), muR, repmat(sigma, 1, T))));
            Results(i, j).mlpd = mean(Results(i, j).lpd);
        end
        
        if plotParams
            for ip = 1:length(Params)
                f(10+ip) = figure(10000*j+ip+1);
                f(10+ip).Units = 'normalized';
                f(10+ip).OuterPosition = [0 0.032 1 0.968];
                subplot(nrows, ncols, i)
                pgrid = linspace(ParamLims{ip}(1), ParamLims{ip}(2));
                [pd, ~] = ksdensity(Params{ip}, pgrid);
                plot(pgrid, pd)
                set(gca, 'XLim', ParamLims{ip})
                box off
                set(gca, 'YTick', [])
                if ns ~= i
                    title([num2str(Year(ns-i)) ' (N = ' num2str(T) ')'])
                else
                    title(['Prior predictive (N = ' num2str(T) ')'])
                end
            end
        end
        
        %% SIGMA2
        if plotSigma2
            ip = length(Params) + 1;
            f(10+ip) = figure(10000*j+ip+1);
            f(10+ip).Units = 'normalized';
            f(10+ip).OuterPosition = [0 0.032 1 0.968];
            subplot(nrows, ncols, i)
            pgrid = linspace(sigma2Low, sigma2Up);
            [psigma2, ~] = ksdensity(sigma2, pgrid);
            plot(pgrid, psigma2)
            set(gca, 'XLim', [sigma2Low sigma2Up])
            box off
            set(gca, 'YTick', [])
            if ns ~= i
                title([num2str(Year(ns-i)) ' (N = ' num2str(T) ')'])
            else
                title(['Prior predictive (N = ' num2str(T) ')'])
            end
        end
        
        %% S0
        if plotS0
            if strcmp(RSmodels{j}, 'sl') || strcmp(RSmodels{j}, 'sbh')
                ip = length(Params) + 2;
                f(10+ip) = figure(10000*j+ip+1);
                f(10+ip).Units = 'normalized';
                f(10+ip).OuterPosition = [0 0.032 1 0.968];
                subplot(nrows, ncols, i)
                pgrid = linspace(XLim(1), XLim(2));
                [pS0, ~] = ksdensity(S0, pgrid);
                plot(pgrid, pS0)
                set(gca, 'XLim', XLim)
                box off
                set(gca, 'YTick', [])
                if ns ~= i
                    title([num2str(Year(ns-i)) ' (N = ' num2str(T) ')'])
                else
                    title(['Prior predictive (N = ' num2str(T) ')'])
                end
            end
        end
        
        %% PLOT POSTERIOR PROBABILITY DENSITY FUNCTIONS
        if plotC
            if strcmp(RSmodels{j}, 'sl') || strcmp(RSmodels{j}, 'sbh')
                f(j+2) = figure(10000*j);
                f(j+2).Units = 'normalized';
                f(j+2).OuterPosition = [0 0.032 1 0.968];
                subplot(nrows, ncols, i)
                cgrid = sort([linspace(cLow, cUp) 1]);
                i1 = find(cgrid == 1);
                [pc, cgrid] = ksdensity(c, cgrid);
                plot(cgrid, pc)
                set(gca, 'XLim', [cLow cUp])
                hold on
                ylimmax = max(get(gca, 'ylim'));
                plot([1 1], [0 ylimmax], '--k')
                box off
                set(gca, 'YTick', [])
                pless = sum(c<1)/length(c);
                pless = round(pless*100)/100;
                pmore = 1-pless;
                text(0.3, 0.2*max(get(gca, 'ylim')), [num2str(100*pless) ' %'])
                text(mean([mean(get(gca, 'xlim')) max(get(gca, 'xlim'))]), ...
                    0.2*max(get(gca, 'ylim')), [num2str(100*pmore) ' %'])
                if ns ~= i
                    title([num2str(Year(ns-i)) ' (N = ' num2str(T) ')'])
                else
                    title(['Prior predictive (N = ' num2str(T) ')'])
                end
                set(gca, 'YLim', [0 ylimmax])
            end
        end
        
        if plotR || plotRpS
            Sgrid = linspace(XLim(1), XLim(2), 1000);
            lSgrid = length(Sgrid);
            
            SIGMA = repmat(sigma, 1, lSgrid);
            SG = repmat(Sgrid, iter, 1);
            
            switch I(j)
                case 1
                    K = repmat(k, 1, lSgrid);
                    SK = repmat(Sk, 1, lSgrid);
                    RM = K.*(SG./SK).*exp(1-SG./SK);
                case 2
                    RINF = repmat(Rinf, 1, lSgrid);
                    SQ = repmat(Sq, 1, lSgrid);
                    RM = RINF./((1-q)/q*(SQ./SG)+1);
                case 3
                    K = repmat(k, 1, lSgrid);
                    SK = repmat(Sk, 1, lSgrid);
                    C = repmat(c, 1, lSgrid);
                    RM = K.*(SG./SK).^C.*exp(C.*(1-SG./SK));
                case 4
                    RINF = repmat(Rinf, 1, lSgrid);
                    SQ = repmat(Sq, 1, lSgrid);
                    C = repmat(c, 1, lSgrid);
                    RM = RINF./((1-q)/q*(SQ./SG).^C+1);
            end
            
            RP = zeros(reps*iter, 1000);
            for irep = 1:reps % DRAW EXTRA SAMPLES FOR SMOOTHER LINES
                RP(((irep-1)*iter+1):irep*iter, :) = lognrnd(log(RM), SIGMA);
            end
            %RP = lognrnd(log(RM), SIGMA);
            
        end
        
        %% PLOT POSTERIOR PREDICTIVE OF R
        if plotR
            f_R_1 = figure(10000*j+1);
            subplot(nrows, ncols, i)
            
            ERm = mean(RM);
            QRmLow = quantile(RM, qlow);
            QRmUp = quantile(RM, qup);
            
            ERp = mean(RP);
            QRpLow = quantile(RP, qlow);
            QRpUp = quantile(RP, qup);
            
            plot(Sgrid, ERm, '-k', 'linewidth', 2)
            hCM = fill([Sgrid fliplr(Sgrid)], [QRmLow fliplr(QRmUp)], [0.6 0.6 0.6], ...
                'edgecolor', 'none');
            hCP = fill([Sgrid fliplr(Sgrid)], [QRpLow fliplr(QRpUp)], [0.8 0.8 0.8], ...
                'edgecolor', 'none');
            uistack(hCM, 'bottom')
            uistack(hCP, 'bottom')
            
            YMax(i, j) = max(cellfun(@max, get(get(gca, 'Children'), 'YData')));
            
            if ns ~= i
                title([num2str(Year(ns-i)) ' (N = ' num2str(T) ')'])
            else
                title(['Prior predictive (N = ' num2str(T) ')'])
            end
            
            if i == 1
                f_R_2 = figure(1000*j-1);
                copyobj(f_R_1.Children, f_R_2)
                f_R_2.Children(1).Position = [0.1 0.1 0.8 0.8];
                hgsave(f_R_2, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
                    resultLoc, ...
                    'R_S0', prior, sigmaLow, sigmaUp, ...
                    Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                    Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                    RSmodels{j}))
                close(f_R_2)
            end
        end
        
        %% PLOT POSTERIOR PREDICTIVE OF R/S
        if plotRpS
            f_RpS_1 = figure(10000*j-1);
            subplot(nrows, ncols, i)
            
            RpSM = RM./Sgrid;
            ERpSm = mean(RpSM);
            QRpSmLow = quantile(RpSM, qlow);
            QRpSmUp = quantile(RpSM, qup);
            
            RpSP = RP./Sgrid;
            
            ERpSp = mean(RpSP);
            QRpSpLow = quantile(RpSP, qlow);
            QRpSpUp = quantile(RpSP, qup);
            
            plot(Sgrid(2:end), ERpSm(2:end), '-k', 'linewidth', 2)
            hCM = fill([Sgrid(2:end) fliplr(Sgrid(2:end))], [QRpSmLow(2:end) fliplr(QRpSmUp(2:end))], [0.6 0.6 0.6], ...
                'edgecolor', 'none');
            hCP = fill([Sgrid(2:end) fliplr(Sgrid(2:end))], [QRpSpLow(2:end) fliplr(QRpSpUp(2:end))], [0.8 0.8 0.8], ...
                'edgecolor', 'none');
            uistack(hCM, 'bottom')
            uistack(hCP, 'bottom')
            
            YMax(i, j) = max(cellfun(@max, get(get(gca, 'Children'), 'YData')));
            
            if ns ~= i
                title([num2str(Year(ns-i)) ' (N = ' num2str(T) ')'])
            else
                title(['Prior predictive (N = ' num2str(T) ')'])
            end
            
            if i == 1
                f_RpS_2 = figure(1000*j-1);
                copyobj(f_RpS_1.Children, f_RpS_2)
                f_RpS_2.Children(1).Position = [0.1 0.1 0.8 0.8];
                hgsave(f_RpS_2, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
                    resultLoc, ...
                    'RpS_S0', prior, sigmaLow, sigmaUp, ...
                    Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                    Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                    RSmodels{j}))
                close(f_RpS_2)
            end
        end
    end
end

%%
YMax = 300;


%%
if plotR
    for j = 1:length(RSmodels)
        figure(10000*j+1)
        ax = get(10000*j+1, 'Children');
        for i = 1:length(ax)
            ax(i).YLim = [0 1.1*max(max(YMax))];
        end
        
        fixFigureLayout(ax, nrows, ncols, 0:25:500, 0:100:500)
        
        hgsave(10000*j+1, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
            resultLoc, ...
            'R', prior, sigmaLow, sigmaUp, ...
            Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
            Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
            RSmodels{j}))
        print(10000*j+1, sprintf('%s/png/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.png', ...
            resultLoc, ...
            'R', prior, sigmaLow, sigmaUp, ...
            Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
            Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
            RSmodels{j}), '-dpng', '-r150')
    end
end

%%
if plotRpS
    for j = 1:length(RSmodels)
        figure(10000*j-1)
        ax = get(10000*j-1, 'Children');
        for i = 1:length(ax)
            ax(i).YLim = [0 1.5];
        end
        
        fixFigureLayout(ax, nrows, ncols, 0:25:500, 0:0.3:1.5)

        hgsave(10000*j-1, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
            resultLoc, ...
            'RpS', prior, sigmaLow, sigmaUp, ...
            Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
            Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
            RSmodels{j}))
        print(10000*j-1, sprintf('%s/png/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.png', ...
            resultLoc, ...
            'RpS', prior, sigmaLow, sigmaUp, ...
            Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
            Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
            RSmodels{j}), '-dpng', '-r150')
    end
end

%%
if plotC
    for j = 1:length(RSmodels)
        if strcmp(RSmodels{j}, 'sl') || strcmp(RSmodels{j}, 'sbh')
            figure(10000*j)
            ax = get(10000*j, 'Children');
            
            fixFigureLayout(ax, nrows, ncols, 0:1:5, [])
            
            hgsave(10000*j, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
                resultLoc, ...
                'c', prior, sigmaLow, sigmaUp, ...
                Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                RSmodels{j}))
            print(10000*j, sprintf('%s/png/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.png', ...
                resultLoc, ...
                'c', prior, sigmaLow, sigmaUp, ...
                Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                RSmodels{j}), '-dpng', '-r150')
        end
    end
end

%%
for j = 1:length(RSmodels)

    if plotParams
                
        for ip = 1:length(Paramnames{j})
            figure(10000*j+ip+1)
            ax = get(10000*j+ip+1, 'Children');
            
            fixFigureLayout(ax, nrows, ncols, [], [])

            hgsave(10000*j+ip+1, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
                resultLoc, ...
                Paramnames{j}{ip}, prior, sigmaLow, sigmaUp, ...
                Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                RSmodels{j}))
            print(10000*j+ip+1, sprintf('%s/png/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.png', ...
                resultLoc, ...
                Paramnames{j}{ip}, prior, sigmaLow, sigmaUp, ...
                Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                RSmodels{j}), '-dpng', '-r150')
        end
    end
    
    %%
    if plotSigma2
        ip = length(Paramnames{j}) + 1;
        figure(10000*j+ip+1)
        ax = get(10000*j+ip+1, 'Children');
        
        fixFigureLayout(ax, nrows, ncols, 0:0.2:1, [])
        
        hgsave(10000*j+ip+1, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
            resultLoc, ...
            'sigma2', prior, sigmaLow, sigmaUp, ...
            Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
            Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
            RSmodels{j}))
        print(10000*j+ip+1, sprintf('%s/png/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.png', ...
            resultLoc, ...
            'sigma2', prior, sigmaLow, sigmaUp, ...
            Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
            Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
            RSmodels{j}), '-dpng', '-r150')
        
        if strcmp(RSmodels{j}, 'sl') || strcmp(RSmodels{j}, 'sbh')
            ip = length(Params) + 2;
            figure(10000*j+ip+1)
            ax = get(10000*j+ip+1, 'Children');
            
            fixFigureLayout(ax, nrows, ncols, [], [])
            
            hgsave(10000*j+ip+1, sprintf('%s/fig/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.fig', ...
                resultLoc, ...
                'S0', prior, sigmaLow, sigmaUp, ...
                Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                RSmodels{j}))
            print(10000*j+ip+1, sprintf('%s/png/%s_%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.png', ...
                resultLoc, ...
                'S0', prior, sigmaLow, sigmaUp, ...
                Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
                Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
                RSmodels{j}), '-dpng', '-r150')
        end
        
        save(sprintf('%s/mat/%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s.mat', ...
            resultLoc, ...
            prior, sigmaLow, sigmaUp, ...
            Paramnames{j}{1}, ParamLims{1}(1), ParamLims{1}(2), ...
            Paramnames{j}{2}, ParamLims{2}(1), ParamLims{2}(2), ...
            RSmodels{j}), ...
            'Results')
        
    end
end