resultLoc = [cd '/Results'];
prior = 'uniform_sigma2';
sigmaLow = 0.0;
sigmaUp = sqrt(1);
Paramnames = {'Rinf', 'Sq'};
ParamLims = {[0 200], [0 200]};
RSmodel = 'sbh';

casename = sprintf('%s_%.1f-%.1f_%s_%i-%i_%s_%i-%i_%s', ...
    prior, sigmaLow, sigmaUp, ...
    Paramnames{1}, ParamLims{1}(1), ParamLims{1}(2), ...
    Paramnames{2}, ParamLims{2}(1), ParamLims{2}(2), ...
    RSmodel);

figfile = sprintf('%s/fig/%s_%s.fig', ...
    resultLoc, 'RpS_S0', casename);

f = openfig(figfile);
f.Units = 'normalized';
f.Position = [0.010 0.086 0.451 0.565];
ax1 = f.Children;

%%
matfile = sprintf('%s/mat/%s.mat', ...
    resultLoc, casename);

load(matfile)

%%
ax1.TickDir = 'out';
ax1.YLabel.String = 'Recruits-per-spawner';
ax1.XLabel.String = 'Spawning stock biomass';
ax1.Title.String = '';
ax1.FontSize = 16;
ax1.Position = [0.1 0.115 0.85 0.8];
ax1.YLim = [0 1.4];

%%
ax2 = axes;
ax2.Position = ax1.Position;

%%
S0 = Results(1,4).S0;
XLim = get(ax1, 'XLim');
pgrid = linspace(XLim(1), XLim(2));
[pS0, ~] = ksdensity(S0, pgrid);
x = linspace(XLim(1), XLim(2), length(pS0));
YLim = get(gca, 'YLim');
y = linspace(YLim(1), YLim(2), 2);
[X, Y] = meshgrid(x, y);
PS0 = repmat(pS0, length(y), 1);
hsurf = surf(X, Y, PS0);
shading interp

%%
view(0, 90)

%%
hsurf.FaceAlpha = 0.5;

%%
ax2.XLim = ax1.XLim;

%%
n = 100;
map = [repmat(255, n, 1), linspace(255, 0, n)', linspace(255, 0, n)']/255;
colormap(ax2, map)

%%
grid off
ax2.YTick = [];
ax2.XTick = [];
ax2.Color = 'none';

%%
ax3 = axes;
ax3.Position = ax1.Position;
uistack(ax3, 'top')
ax3.YTick = [];
ax3.XTick = [];
ax3.Color = 'none';

copyobj(findobj(ax1.Children, 'Type', 'Line'), ax3)
delete(findobj(ax1.Children, 'Type', 'Line'))

ax3.XLim = ax1.XLim;
ax3.YLim = ax1.YLim;

hold on

%%
idl = 2;
ax3.Children(idl).LineStyle = ':';
ax3.Children(idl).LineWidth = 1;
ax3.Children(idl).Marker = '.';
ax3.Children(idl).MarkerSize = 16;

%%
ax1.Children(1).FaceColor = 0.25*ones(1,3);
ax1.Children(2).FaceColor = 0.65*ones(1,3);

%%
ax4 = axes;
ax4.Position = ax1.Position;
ax4.Position(4) = 1.035*ax1.Position(4);

%%
S0_up = quantile(S0, 0.975);
S0_low = quantile(S0, 0.025);
h = 0.04;
yc = 1.38;
hmm = plot([S0_low S0_up], [yc yc], '-k', 'linewidth', 1.5);
hold on
hmml = plot([S0_low S0_low], yc+h*[-.5 .5], '-k', 'linewidth', 1.5);
hmmr = plot([S0_up S0_up], yc+h*[-.5 .5], '-k', 'linewidth', 1.5);

%%
ax4.XLim = ax1.XLim;
ax4.YLim = ax1.YLim;
ax4.XAxis.Visible = 'off';
ax4.YAxis.Visible = 'off';
ax4.Color = 'none';

%%
ht1 = text(ax3, 0, 0, 'Allee effect zone');
ht1.FontSize = 16;
ht1.Position = [9.5 1.25 0];

%%
S0_med = quantile(S0, 0.5);

%%
ht2 = text(0, 0, '95% CPI'); 
ht2.FontSize = 14;
ht2.Position = [S0_med-11.5 1.43 0];

%%
hS0 = plot(ax3, [S0_med S0_med], ylim, '-r', 'LineWidth', 1);

axes(ax3)

%%
% 1959 = 1
% 1965 = 7
% 1971 = 13
% 1974 = 16
% 1977 = 19
% 2008 = 50

load('SR_modeloutput_3Pscod_revised.mat')

Data(:,3) = Data(:,3)./Data(:,2);

ht1959 = text(Data(1,2), Data(1,3), num2str(Data(1,1)));
ht2008 = text(Data(50,2), Data(50,3), num2str(Data(50,1)));
ht1965 = text(Data(7,2), Data(7,3), num2str(Data(7,1)));
ht1971 = text(Data(13,2), Data(13,3), num2str(Data(13,1)));
ht1974 = text(Data(16,2), Data(16,3), num2str(Data(16,1)));
ht1977 = text(Data(19,2), Data(19,3), num2str(Data(19,1)));

ht1959.FontSize = 16;
ht2008.FontSize = 16;
ht1965.FontSize = 16;
ht1971.FontSize = 16;
ht1974.FontSize = 16;
ht1977.FontSize = 16;

ht1959.Color = 'b';
ht2008.Color = 'b';
ht1965.Color = 'b';
ht1971.Color = 'b';
ht1974.Color = 'b';
ht1977.Color = 'b';

%%
offset_r = [2.3885 0.0020 0];
offset_l = [-21 0.0072 0];

%%
ht1959.Position = ht1959.Position + offset_r;
ht2008.Position = ht2008.Position + offset_l;

%%
ht1965.Position = ht1965.Position + offset_r;
ht1971.Position = ht1971.Position + offset_r;
ht1974.Position = ht1974.Position + offset_l;
ht1977.Position = ht1977.Position + offset_r;

%%
hc1 = plot(Data([1 50],2), Data([1 50],3), 'bo');
hc1.MarkerSize = 7;

%%
hc2 = plot(Data([7 13 16 19],2), Data([7 13 16 19],3), 'bo');
hc2.MarkerSize = 7;

%%
uistack(ht1, 'top')

%%
hgsave(sprintf('%s/fig/RpS_S0_final_%s.%s', resultLoc, casename, 'fig'))
print(sprintf('%s/png/RpS_S0_final_%s.%s', resultLoc, casename, 'png'), '-dpng', '-r150')